abacusai.model_location — AbacusAI documentation

# abacusai.model_location

## Classes

`AbstractApiClass` |
`ModelLocation` | Provide location information for the plug-and-play model.

## Module Contents

class abacusai.model_location.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.model_location.ModelLocation(client, location=None, artifactNames=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Provide location information for the plug-and-play model.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - location (str) – Location of the plug-and-play model.

    - artifactNames (dict) – Representations of the names of the artifacts used to create the model.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict